/* Reproducibility code for :

  "WHICH DATA DO ECONOMISTS USE TO STUDY CORRUPTION? A CROSS-SECTION OF CORRUPTION RESEARCH"
  by James H. Anderson and Akanksha Baidya
  
  This program uses two datasets:
	- Use of Corruption Data by Economists.dta . Includes data on 339 articles which were in search results and include JEL codes. This is the main sample used for most of the paper.
	- Use of Corruption Data by Economists_Longlist.dta . Includes some basic information on 883 articles which were in search results, whether or not they included JEL codes.
    
  A few notes on the program:
	- The program reproduces the tables and text references in the order they appear in the paper.
	- The program generates a large number of temporary datasets (called temp*.dta) which will be placed in the same folder. These can be deleted.	
	- For each table, some lines of code produce the information needed to populate the tables. These are mostly intuitive. In addition, a separate section produces the results and outputs them into separate Excel files (called Table*.xls).
		
*/

clear

*******************************************
* Replace with local folder.
* Place both data files and this do file in this same folder.

cd  "C:\WBG\github\274-v3\s (3)\s"

use "Use of Corruption Data by Economists.dta", clear

save temp, replace


*******************************************
* Text reference: Of the 339 articles in the basic sample, 177 were published in journals included in the CL-Index, and 35 were in journals ranked in the top 100 of the Combes & Linnemer list (CL-Index Top 100). 

sum cl_index 
sum cl_index_top100 if  cl_index_top100 > 0


*******************************************
* Text reference: Of the 339 articles on corruption in our basic sample, 282 were in journals or series included in the IDEAS/Repec H-Index rankings, and 30 were published in journals ranked in the top 100 (IDEAS/RePEc H-Index Top 100). 

sum repec_rank 
sum repec_rank_top100 if repec_rank_top100 > 0


*******************************************
* Table 1. Articles published in highly ranked economics journals
*
* Table 1 is based on the sample of 339 articles.


tab publication if repec_rank_top100 == 1
tab publication if cl_index_top100 == 1

* This section produces an Excel file called Table 1. 
replace repec_rank_top100 = . if repec_rank_top100 == 0
replace cl_index_top100 = . if cl_index_top100 == 0
keep publication repec_rank_top100 cl_index_top100
keep if repec_rank_top100 == 1 | cl_index_top100 == 1
collapse (count) repec_rank_top100 cl_index_top100, by(publication)
replace repec_rank_top100 = . if repec_rank_top100 == 0
replace cl_index_top100 = . if cl_index_top100 == 0
export excel using "Table1", firstrow(variables) replace
clear


*******************************************
* Preparation for Tables 2 and 3.
*
* Since each paper has multiple JEL codes, a new dataset is created with a simple list of JEL codes. This is done by creating and appending together nine files, each with a simple list of JEL codes based on jel1 - jel9.
* Note: Two articles had JEL codes with extra zeros at the ends. These were presumed to be to 2-digit JEL codes and the final 0 was dropped.

use "Use of Corruption Data by Economists.dta", clear
save temp, replace

foreach var of varlist jel1 jel2 jel3 jel4 jel5 jel6 jel7 jel8 jel9 {
	use "Use of Corruption Data by Economists.dta", clear
save temp, replace
keep `var' title
quietly replace `var' = "C30" if `var' == "C300"
quietly replace `var' = "D72" if `var' == "D720"
quietly replace `var' = "D73" if `var' == "D730"
quietly replace `var' = "H11" if `var' == "H110"
quietly replace `var' = "O13" if `var' == "O130"
quietly replace `var' = "O17" if `var' == "O170"
quietly replace `var' = "Q34" if `var' == "Q340"
quietly replace `var' = "Q38" if `var' == "Q380"
gen jelj = `var'
save temp`var', replace
}

clear 

append using "tempjel1.dta" "tempjel2.dta" "tempjel3.dta" "tempjel4.dta" "tempjel5.dta" "tempjel6.dta" "tempjel7.dta" "tempjel8.dta" "tempjel9.dta"

quietly replace jelj = subinstr(jelj, " ", "", .)

keep if jelj ~= ""
keep title jelj

* Dropping duplicates. Since some articles may indicate JEL codes one of which is subsumed in the other, the approach used above could lead to duplicates. The following code generates a variable called dup which is 0 if unique, 1 if the first occurance, 2, if the second occurance, etc. We will drop those for which dup >= 2.

sort title jelj
quietly by title jelj:  gen dup = cond(_N==1,0,_n)

* tab dup

quietly drop if dup >=2
		
quietly drop dup 

save temp, replace


*******************************************
* Table 2. Frequencies of JEL Categories for articles in the full sample

use temp, clear
gen jeljbig = ""
foreach new of newlist A B C D E F G H I J K L M N O P Q R Y Z {
	gen jeljbig`new' = strpos(jelj, "`new'") > 0
	quietly replace jeljbig = "`new'" if jeljbig`new' == 1 & jeljbig == ""
}

* We again need to deal with the possibility of duplicates.

keep title jeljbig
sort title jeljbig
quietly by title jeljbig:  gen dupjelbig = cond(_N==1,0,_n)
	quietly drop if dupjelbig >=2
	
* This produces the simple list as it appears in the paper.
tab jeljbig

* This section produces an Excel file called Table 2 matching the list of JEL codes. 
keep jeljbig 
gen thenumberone = 1
collapse (count) thenumberone, by(jeljbig)

quietly replace jeljbig =  "A.	general economics and teaching" if jeljbig == "A" 
quietly replace jeljbig =  "B.	history of economic thought, methodology, and heterodox approaches" if jeljbig == "B"
quietly replace jeljbig =  "C. 	mathematical and quantitative methods" if jeljbig == "C" 
quietly replace jeljbig =  "D. 	microeconomics" if jeljbig == "D" 
quietly replace jeljbig =  "E. 	macroeconomics and monetary economics" if jeljbig == "E" 
quietly replace jeljbig =  "F. 	international economics" if jeljbig == "F" 
quietly replace jeljbig =  "G. 	financial economics" if jeljbig == "G" 
quietly replace jeljbig =  "H. 	public economics" if jeljbig == "H" 
quietly replace jeljbig =  "I. 	health, education, and welfare" if jeljbig == "I" 
quietly replace jeljbig =  "J. 	labor and demographic economics" if jeljbig == "J" 
quietly replace jeljbig =  "K. 	law and economics" if jeljbig == "K" 
quietly replace jeljbig =  "L. 	industrial organization" if jeljbig == "L" 
quietly replace jeljbig =  "M.	business administration and business economics ◦ marketing ◦ accounting ◦ personnel economics" if jeljbig == "M" 
quietly replace jeljbig =  "N. 	economic history" if jeljbig == "N" 
quietly replace jeljbig =  "O. 	economic development, innovation, technological change, and growth" if jeljbig == "O" 
quietly replace jeljbig =  "P. 	political economy and comparative economic systems" if jeljbig == "P" 
quietly replace jeljbig =  "Q. 	agricultural and natural resource economics ◦ environmental and ecological economics" if jeljbig == "Q" 
quietly replace jeljbig =  "R. 	urban, rural, regional, real estate, and transportation economics" if jeljbig == "R" 
quietly replace jeljbig =  "Y. 	miscellaneous categories" if jeljbig == "Y" 
quietly replace jeljbig =  "Z. 	other special topics" if jeljbig == "Z" 

rename jeljbig JEL_Category
rename thenumberone frequency

export excel using "Table2", firstrow(variables) replace
clear


*******************************************
* Table 3. Frequencies of the most common JEL Codes for the full sample.
*
* Table 3 has a subset of results for which the frequency is >= 10.

* Generate a new temporary dataset with the number of observations:
use temp, clear
gen thenumberone = 1
collapse (count) thenumberone, by(jelj)
gsort -thenumberone jelj
list jelj thenumberone if thenumberone >= 10 & thenumberone ~= . & jelj ~= ""
keep if thenumberone >= 10 & thenumberone ~= . & jelj ~= ""

quietly replace jelj = "D73. bureaucracy ◦ administrative processes in public organizations ◦ corruption" if jelj == "D73"
quietly replace jelj = "O17. formal and informal sectors ◦ shadow economy ◦ institutional arrangements" if jelj == "O17"
quietly replace jelj = "D72. political processes: rent-seeking, lobbying, elections, legislatures, and voting behavior" if jelj == "D72"
quietly replace jelj = "K42. illegal behavior and the enforcement of law" if jelj == "K42"
quietly replace jelj = "G21. banks ◦ depository institutions ◦ micro finance institutions ◦ mortgages" if jelj == "G21"
quietly replace jelj = "O16. financial markets ◦ saving and capital investment ◦ corporate finance and governance" if jelj == "O16"
quietly replace jelj = "P26. property rights" if jelj == "P26"
quietly replace jelj = "O11. macroeconomic analyses of economic development" if jelj == "O11"
quietly replace jelj = "O15. human resources ◦ human development ◦ income distribution ◦ migration" if jelj == "O15"
quietly replace jelj = "F23. multinational firms ◦ international business" if jelj == "F23"
quietly replace jelj = "G32. financing policy ◦ financial risk and risk management ◦ capital and ownership structure ◦ value of firms ◦ goodwill" if jelj == "G32"
quietly replace jelj = "O19. international linkages to development ◦ role of international organizations" if jelj == "O19"
quietly replace jelj = "O43. institutions and growth" if jelj == "O43"
quietly replace jelj = "M14. corporate culture ◦ diversity ◦ social responsibility" if jelj == "M14"
quietly replace jelj = "O14. industrialization ◦ manufacturing and service industries ◦ choice of technology" if jelj == "O14"
quietly replace jelj = "D22. firm behavior: empirical analysis" if jelj == "D22"
quietly replace jelj = "H11. structure, scope, and performance of government" if jelj == "H11"
quietly replace jelj = "L25. firm performance: size, diversification, and scope" if jelj == "L25"
quietly replace jelj = "O13. agriculture ◦ natural resources ◦ energy ◦ environment ◦ other primary products" if jelj == "O13"
quietly replace jelj = "G34. mergers ◦ acquisitions ◦ restructuring ◦ corporate governance" if jelj == "G34"
quietly replace jelj = "E02. institutions and the macroeconomy" if jelj == "E02"
quietly replace jelj = "F14. empirical studies of trade" if jelj == "F14"
quietly replace jelj = "C23. panel data models ◦ spatio-temporal models" if jelj == "C23"
quietly replace jelj = "F21. international investment ◦ long-term capital movements" if jelj == "F21"
quietly replace jelj = "G38. government policy and regulation" if jelj == "G38"

rename jelj JEL_Category
rename thenumberone frequency

export excel using "Table3", firstrow(variables) replace
clear


*******************************************
* Table 4. Numbers of articles by geographic focus
*
* Table 4 is based on on the article-level dataset of 339 observations.

use "Use of Corruption Data by Economists.dta", clear
save temp, replace

gen empirical_dummy = (empirical == "Empirical" | empirical == "Both")
gen ranked_journal = (cl_index ~= . | repec_rank ~= .)
gen topranked_journal = (cl_index_top100 == 1 | repec_rank_top100 == 1)

* For the totals at the bottom of the top panel of Table 4:
tab empirical_dummy
tab ranked_journal if empirical_dummy == 1
tab topranked_journal if empirical_dummy == 1

* For the totals at the bottom of the bottom panel of Table 4:
tab empirical_dummy if single == 1
tab empirical_dummy if single == 1 & ranked_journal == 1
tab empirical_dummy if single == 1 & topranked_journal == 1

* Note that in the data file Hong Kong, China is listed as a separate geography from China. These are combined in the table in the paper to refer to "China".
replace geography = "China" if geography == "Hong Kong, China"

foreach var of varlist world regional affinity single comparative allgeog {
	*Empirical articles
	table `var' empirical_dummy if `var' == 1 & empirical_dummy == 1
	*Empirical articles in ranked journals
	table `var' ranked_journal if `var' == 1 & ranked_journal == 1 & empirical_dummy == 1
	*Empirical articles in top 100 ranked journals
	table `var' topranked_journal if `var' == 1 & topranked_journal == 1 & empirical_dummy == 1
}

save temp, replace

* Generate a new temporary dataset with the number of observations. As before, since a single paper can cover multiple categories, we will create different datasets and append one to another.
* This requires several steps. The temporary datafiles will then be merged together by title.

use temp, clear
foreach var of varlist world regional affinity single comparative allgeog {
	use temp, clear
	gen geography2 = "`var'"
	keep `var' title empirical_dummy ranked_journal topranked_journal geography2 
	gen `var'j = `var'
	keep if `var' == 1 & empirical_dummy == 1
	save temp`var', replace
	clear
}

clear

append using "tempworld.dta" "tempregional.dta" "tempaffinity.dta" "tempsingle.dta" "tempcomparative.dta" "tempallgeog.dta" 
collapse (sum) empirical_dummy ranked_journal topranked_journal, by (geography2)
gen simpleorder = .
replace simpleorder = 1 if geography2 == "world"
replace simpleorder = 2 if geography2 == "regional"
replace simpleorder = 3 if geography2 == "affinity"
replace simpleorder = 4 if geography2 == "single"
replace simpleorder = 5 if geography2 == "comparative"
replace simpleorder = 6 if geography2 == "allgeog"
replace geography2 = "total" if geography2 == "allgeog"
sort simpleorder

* Export the top part of Table 4
drop simpleorder
export excel using "Table4Top", firstrow(variables) replace
clear

* Prepare for the bottom part of Table 4 for single-geography studies.
* This is a bit simpler since these map one to one for articles.

use temp, clear
keep if empirical_dummy == 1 & single == 1
keep title single ranked_journal topranked_journal geography
collapse (sum) single ranked_journal topranked_journal, by (geography)

* Export the bottom part of Table 4

export excel using "Table4Bottom", firstrow(variables) replace
clear


*******************************************
* Table 5. Data sources for studies on corruption, by geographical category
* List of key data sources: wgi wbentsurvey lits wbusenvsurvey99 cpi gcb afrobarom icrg vdem cpia fcpa bbva wvs bci eqgi wef basel thomsonreuters other_survey experiment admin_data

use "Use of Corruption Data by Economists.dta", clear
save temp, replace

gen empirical_dummy = (empirical == "Empirical" | empirical == "Both")
gen ranked_journal = (cl_index ~= . | repec_rank ~= .)
gen topranked_journal = (cl_index_top100 == 1 | repec_rank_top100 == 1)

* These save the number of observations used later in the program.
* First column
sum wgi cpi icrg wbentsurvey vdem bci wef lits wvs eqgi basel wbusenvsurvey99 afrobarom fcpa bbva thomsonreuters other_survey experiment admin_data if empirical_dummy == 1
gen jim_denom_1 = r(N)
* Second column
sum wgi cpi icrg wbentsurvey vdem bci wef lits wvs eqgi basel wbusenvsurvey99 afrobarom fcpa bbva thomsonreuters other_survey experiment admin_data if empirical_dummy == 1 & (world == 1 | regional == 1 | affinity == 1)
gen jim_denom_2 = r(N)
* Third column
sum wgi cpi icrg wbentsurvey vdem bci wef lits wvs eqgi basel wbusenvsurvey99 afrobarom fcpa bbva thomsonreuters other_survey experiment admin_data if empirical_dummy == 1 & (single == 1 | comparative == 1)
gen jim_denom_3 = r(N)

sum jim_denom_1 jim_denom_2 jim_denom_3
save temp, replace

* Create Table 5
keep if empirical_dummy == 1
gen world_regional_affinity = 1 if world == 1 | regional == 1 | affinity == 1
gen single_comparative = 1 if single == 1 | comparative == 1
keep title single empirical_dummy ranked_journal topranked_journal wgi cpi icrg wbentsurvey vdem bci wef lits wvs eqgi basel wbusenvsurvey99 afrobarom fcpa bbva thomsonreuters other_survey experiment admin_data world_regional_affinity single_comparative jim_denom* cl_index cl_index_top100 repec_rank repec_rank_top100 causes_of_corruption corr_as_a_cause
save temp, replace

* For the totals at the bottom of Table 5
tab empirical_dummy
tab world_regional_affinity 
tab single_comparative 


use temp, clear
foreach var of varlist wgi cpi icrg wbentsurvey vdem bci wef lits wvs eqgi basel wbusenvsurvey99 afrobarom fcpa bbva thomsonreuters other_survey experiment admin_data {
	use temp, clear
	keep `var' title world_regional_affinity single_comparative empirical_dummy ranked_journal topranked_journal jim_denom* cl_index cl_index_top100 repec_rank repec_rank_top100 causes_of_corruption corr_as_a_cause
	gen data_source = ""
	replace data_source = "`var'" if `var' == 1
	keep if `var' == 1
	save temp_`var', replace
	clear
}

clear
append using "temp_wgi.dta" "temp_cpi.dta" "temp_icrg.dta" "temp_wbentsurvey.dta" "temp_vdem.dta" "temp_bci.dta" "temp_wef.dta" "temp_lits.dta" "temp_wvs.dta" "temp_eqgi.dta" "temp_basel.dta" "temp_wbusenvsurvey99.dta" "temp_afrobarom.dta" "temp_fcpa.dta" "temp_bbva.dta" "temp_thomsonreuters.dta" "temp_other_survey.dta" "temp_experiment.dta" "temp_admin_data.dta"


collapse (count) empirical_dummy world_regional_affinity single_comparative, by (data_source)
rename empirical_dummy all_data

gen simple_sort2 = .
replace simple_sort2 = 1 if data_source == "wgi"
replace simple_sort2 = 2 if data_source == "cpi"
replace simple_sort2 = 3 if data_source == "icrg"
replace simple_sort2 = 4 if data_source == "wbentsurvey"
replace simple_sort2 = 5 if data_source == "vdem"
replace simple_sort2 = 6 if data_source == "bci"
replace simple_sort2 = 7 if data_source == "wef"
replace simple_sort2 = 8 if data_source == "lits"
replace simple_sort2 = 9 if data_source == "wvs"
replace simple_sort2 = 10 if data_source == "eqgi"
replace simple_sort2 = 11 if data_source == "basel"
replace simple_sort2 = 12 if data_source == "wbusenvsurvey99"
replace simple_sort2 = 13 if data_source == "afrobarom"
replace simple_sort2 = 14 if data_source == "fcpa"
replace simple_sort2 = 15 if data_source == "bbva"
replace simple_sort2 = 16 if data_source == "thomsonreuters"
replace simple_sort2 = 17 if data_source == "other_survey"
replace simple_sort2 = 18 if data_source == "experiment"
replace simple_sort2 = 19 if data_source == "admin_data"
gsort data_source

save temp_table5_p1, replace

* Note that a single article may have multiple data sources --the reason the program gets complicated. To arrive at the percentage of articles in a category (say world_regional_affinity) that use a datasource, one needs to divide by the total number of articles in that category, not the total number of article-data_sources. The following lines create the percentages based on the denominators (scalars) identified earlier.

clear
append using "temp_wgi.dta" "temp_cpi.dta" "temp_icrg.dta" "temp_wbentsurvey.dta" "temp_vdem.dta" "temp_bci.dta" "temp_wef.dta" "temp_lits.dta" "temp_wvs.dta" "temp_eqgi.dta" "temp_basel.dta" "temp_wbusenvsurvey99.dta" "temp_afrobarom.dta" "temp_fcpa.dta" "temp_bbva.dta" "temp_thomsonreuters.dta" "temp_other_survey.dta" "temp_experiment.dta" "temp_admin_data.dta"

collapse (mean) jim_denom*, by (data_source)
sort data_source

merge 1:1 data_source using temp_table5_p1.dta
drop _merge
* Note: the bottom line of Table 5 has the number of papers. This was generated earlier and saved as jim_denom_1, jim_denom_2, and jim_denom_3. They can be seen as the means in this collapsed file.
sum jim_denom_1 jim_denom_2 jim_denom_3

gsort simple_sort2
keep data_source all_data world_regional_affinity single_comparative


* Export the data to Table 5_sources

export excel using "Table5_sources", firstrow(variables) replace


* Export the total number of observations for the final row of Table 5, called Table5_lastrow
use temp, clear

gen onej = 1
collapse (mean) jim_denom*, by (onej)
keep jim_denom_1 jim_denom_2 jim_denom_3
rename jim_denom_1 all_data
rename jim_denom_2 world_regional_affinity
rename jim_denom_3 single_comparative
export excel using "Table5_lastrow", firstrow(variables) replace
clear

*******************************************
* Table 6. Data sources for studies on corruption, for ranked journals

use "Use of Corruption Data by Economists.dta", clear
save temp, replace

* Generate and export the table
clear
append using "temp_wgi.dta" "temp_cpi.dta" "temp_icrg.dta" "temp_wbentsurvey.dta" "temp_vdem.dta" "temp_bci.dta" "temp_wef.dta" "temp_lits.dta" "temp_wvs.dta" "temp_eqgi.dta" "temp_basel.dta" "temp_wbusenvsurvey99.dta" "temp_afrobarom.dta" "temp_fcpa.dta" "temp_bbva.dta" "temp_thomsonreuters.dta" "temp_other_survey.dta" "temp_experiment.dta" "temp_admin_data.dta"

replace cl_index_top100 = . if cl_index_top100 == 0
replace repec_rank_top100 = . if repec_rank_top100 == 0

collapse (count) empirical_dummy  cl_index cl_index_top100 repec_rank repec_rank_top100, by (data_source)
rename empirical_dummy all_data

gen simple_sort2 = .
replace simple_sort2 = 1 if data_source == "wgi"
replace simple_sort2 = 2 if data_source == "cpi"
replace simple_sort2 = 3 if data_source == "icrg"
replace simple_sort2 = 4 if data_source == "wbentsurvey"
replace simple_sort2 = 5 if data_source == "vdem"
replace simple_sort2 = 6 if data_source == "bci"
replace simple_sort2 = 7 if data_source == "wef"
replace simple_sort2 = 8 if data_source == "lits"
replace simple_sort2 = 9 if data_source == "wvs"
replace simple_sort2 = 10 if data_source == "eqgi"
replace simple_sort2 = 11 if data_source == "basel"
replace simple_sort2 = 12 if data_source == "wbusenvsurvey99"
replace simple_sort2 = 13 if data_source == "afrobarom"
replace simple_sort2 = 14 if data_source == "fcpa"
replace simple_sort2 = 15 if data_source == "bbva"
replace simple_sort2 = 16 if data_source == "thomsonreuters"
replace simple_sort2 = 17 if data_source == "other_survey"
replace simple_sort2 = 18 if data_source == "experiment"
replace simple_sort2 = 19 if data_source == "admin_data"
gsort simple_sort2

* Export the data to Table6_sources
drop all_data simple_sort2 
export excel using "Table6_sources", firstrow(variables) replace
clear

* Export the total number of observations for the final row of Table 6, called Table6_lastrow. Start with the original data.
use "Use of Corruption Data by Economists.dta", clear
save temp, replace

gen empirical_dummy = (empirical == "Empirical" | empirical == "Both")
gen ranked_journal = (cl_index ~= . | repec_rank ~= .)
gen topranked_journal = (cl_index_top100 == 1 | repec_rank_top100 == 1)

keep if empirical_dummy == 1 & ranked_journal == 1
keep empirical_dummy cl_index cl_index_top100 repec_rank repec_rank_top100

replace cl_index_top100 = . if cl_index_top100 == 0
replace repec_rank_top100 = . if repec_rank_top100 == 0

gen onej = 1
collapse (count) cl_index cl_index_top100 repec_rank repec_rank_top100, by (onej)

drop onej
export excel using "Table6_lastrow", firstrow(variables) replace
clear


*******************************************
* Text: "For the full sample of articles, 69 percent were tagged as examining the impact that corruption has on something else, such as growth or firm performance, while 24 percent examined the causes of corruption. About 6 percent did both, and about 14 percent did neither."

use temp, clear

* The numbers in the text can be found in this table:
tab corr_as_a_cause causes_of_corruption, row column cell

* The following lines make it somewhat easier to see the same results:
gen bothcauseconseq = (corr_as_a_cause == 1 & causes_of_corruption == 1)
gen neithercauseconseq = (corr_as_a_cause == 0 & causes_of_corruption == 0)
gen eithercauseconseq = (corr_as_a_cause == 1 | causes_of_corruption == 1)
sum corr_as_a_cause causes_of_corruption bothcauseconseq neithercauseconseq


*******************************************
* Table 7. Data sources for studies on corruption, by direction of causality

* Generate and export the table
clear
append using "temp_wgi.dta" "temp_cpi.dta" "temp_icrg.dta" "temp_wbentsurvey.dta" "temp_vdem.dta" "temp_bci.dta" "temp_wef.dta" "temp_lits.dta" "temp_wvs.dta" "temp_eqgi.dta" "temp_basel.dta" "temp_wbusenvsurvey99.dta" "temp_afrobarom.dta" "temp_fcpa.dta" "temp_bbva.dta" "temp_thomsonreuters.dta" "temp_other_survey.dta" "temp_experiment.dta" "temp_admin_data.dta"

replace corr_as_a_cause = . if corr_as_a_cause == 0
replace causes_of_corruption = . if causes_of_corruption == 0
gen cause_or_effect = 1 if corr_as_a_cause == 1 | causes_of_corruption == 1

collapse (count) cause_or_effect corr_as_a_cause causes_of_corruption, by (data_source)

gen simple_sort2 = .
replace simple_sort2 = 1 if data_source == "wgi"
replace simple_sort2 = 2 if data_source == "cpi"
replace simple_sort2 = 3 if data_source == "icrg"
replace simple_sort2 = 4 if data_source == "wbentsurvey"
replace simple_sort2 = 5 if data_source == "vdem"
replace simple_sort2 = 6 if data_source == "bci"
replace simple_sort2 = 7 if data_source == "wef"
replace simple_sort2 = 8 if data_source == "lits"
replace simple_sort2 = 9 if data_source == "wvs"
replace simple_sort2 = 10 if data_source == "eqgi"
replace simple_sort2 = 11 if data_source == "basel"
replace simple_sort2 = 12 if data_source == "wbusenvsurvey99"
replace simple_sort2 = 13 if data_source == "afrobarom"
replace simple_sort2 = 14 if data_source == "fcpa"
replace simple_sort2 = 15 if data_source == "bbva"
replace simple_sort2 = 16 if data_source == "thomsonreuters"
replace simple_sort2 = 17 if data_source == "other_survey"
replace simple_sort2 = 18 if data_source == "experiment"
replace simple_sort2 = 19 if data_source == "admin_data"
gsort simple_sort2

* Export the data to Table7_sources
drop simple_sort2 
export excel using "Table7_sources", firstrow(variables) replace
clear


* Export the total number of observations for the final row of Table 7, called Table7_lastrow. Start with the original data.
use "Use of Corruption Data by Economists.dta", clear
save temp, replace

replace corr_as_a_cause = . if corr_as_a_cause == 0
replace causes_of_corruption = . if causes_of_corruption == 0
gen cause_or_effect = 1 if corr_as_a_cause == 1 | causes_of_corruption == 1

gen onej = 1
collapse (count) cause_or_effect corr_as_a_cause causes_of_corruption, by (onej)

drop onej
export excel using "Table7_lastrow", firstrow(variables) replace
clear



*******************************************
* Text: "Experimental data were used in nearly 14 percent of the papers in the CL-Index Top 100, compared to only 1 percent of papers that are not ranked in that group.  Similarly, administrative data were used in 34 percent of the papers in the CL-Index Top 100, compared to only 15 percent of papers that are not ranked in that group."

use temp, clear

sum experiment if cl_index_top100 == 1
sum experiment if cl_index_top100 == 0
sum admin_data if cl_index_top100 == 1
sum admin_data if cl_index_top100 == 0


*******************************************
* Table 8. Use of data on corruption in economics, political science, and public administration
*
* These tables are based on a longer file of search results and includes articles regardless of whether or not there are JEL codes. Note that the determination of whether or not the paper uses data was only done for papers in publications in one of the Google Scholar top-20 lists.

use "Use of Corruption Data by Economists_Longlist.dta", clear
save temp, replace

* First section on Economics Journals
tab publication if google_ec == 1
tab publication jel_dummy if google_ec == 1 
tab publication usesdata if google_ec == 1 

* Second section on Political Science Journals
tab publication if google_ps == 1
tab publication jel_dummy if google_ps == 1 
tab publication usesdata if google_ps == 1 

* Third section on Public Policy and Administration Journals
tab publication if google_ppa == 1
tab publication jel_dummy if google_ppa == 1 
tab publication usesdata if google_ppa == 1 

* Make the table
use "Use of Corruption Data by Economists_Longlist.dta", clear
save temp, replace

replace google_ec = . if google_ec == 0
replace google_ps = . if google_ps == 0
replace google_ppa = . if google_ppa == 0
replace jel_dummy = . if jel_dummy == 0
replace usesdata = . if usesdata == 0
keep publication google* jel_dummy usesdata
save temp, replace

* top part of Table 8
use temp, clear
keep if google_ec == 1
collapse (count) google_ec jel_dummy usesdata, by(publication)
rename google_ec papers_in_sample
export excel using "Table8top", firstrow(variables) replace

* middle part of Table 8
use temp, clear
keep if google_ps == 1
collapse (count) google_ps jel_dummy usesdata, by(publication)
rename google_ps papers_in_sample
export excel using "Table8middle", firstrow(variables) replace

* bottom part of Table 8
use temp, clear
keep if google_ppa == 1
collapse (count) google_ppa jel_dummy usesdata, by(publication)
rename google_ppa papers_in_sample
export excel using "Table8bottom", firstrow(variables) replace

clear


*******************************************
* Text: "Whereas only 22 percent of articles that were published outside of the CL-Index looked at the causes of corruption, 40 percent of those that were published in CL-Index Top 100 journals did so."

use "Use of Corruption Data by Economists.dta", clear
save temp, replace

sum causes_of_corruption if cl_index == . 
sum causes_of_corruption if cl_index_top100 == 1 
